## GitHub

Overview
4 permissions for all of your repositories
Administration
Access: Read and write
Contents
Access: Read and write
Metadata
Access: Read-only
Variables
Access: Read and write
4 Organization permissions
Administration
Access: Read and write
Members
Access: Read and write
Projects
Access: Read and write
Variables
Access: Read and write
This token will expire on Mon, Sep 23 2024.
